@@ -60,9 +60,11 @@ def get_all_direct_child_nodes(node):
 
 # will return the text (inner html) of a given node
 def get_text_from_node(node):
+    text = node.text
+    if text == '\n        ':
+        return None
     return node.text
 
-
 # will return the text from a specific node
 def get_text(xml_file, node_tag, node_att_name=None, node_att_val=None):
     return get_text_from_node(get_nodes(xml_file, node_tag, node_att_name, node_att_val)[0])
